@@ -10,6 +10,7 @@ import re
 from selenium import webdriver
 from aza_api.map_aza_stock_to_url import map_aza_stock_to_url
 from webdriver_manager.chrome import ChromeDriverManager
+from selenium.webdriver.chrome.service import Service
 
 def get_aza_fundamentals(stock_tic):
     """HTML parser to get stock fundamentals from Avanza.
@@ -19,30 +20,16 @@ def get_aza_fundamentals(stock_tic):
     # Parse "om-aktien.html"
     stock_url = map_aza_stock_to_url(stock_tic, site='om-aktien.html')
 
-    # Synced
-    #session = HTMLSession()
-    #resp = session.get(stock_url)
-    #resp.html.render()
-    #soup = BeautifulSoup(resp.html.html, 'html.parser')
-
-
-    ## Async
-    #asession = AsyncHTMLSession()
-    #resp = await asession.get(stock_url)
-    #await resp.html.arender()
-    ##soup = BeautifulSoup(resp.content, 'html.parser')
-    #soup = BeautifulSoup(resp.html.html, 'html.parser')
-
-    # Selenium
     #chrome_options = Options(
     driver_path = r"lib/chrome_drivers/93_0_4577_63/chromedriver"
     options = webdriver.ChromeOptions()
     options.headless = True
     #driver = webdriver.Chrome(driver_path, chrome_options=options)
     try:
-        driver = webdriver.Chrome(ChromeDriverManager().install(), options=options)
-        print("Loading first worked")
+        s = Service(ChromeDriverManager().install())
+        driver = webdriver.Chrome(service=s, options=options)
     except Exception as e:
+        print(e)
         print("Failed to load Chromedriver install, trying 2nd option..")
         gChromeOptions = webdriver.ChromeOptions()
         gChromeOptions.add_argument("window-size=1920x1480")
